### Chapter 10. Work with PFD Definitions

This chapter provides additional information for working with PFD definitions.

You can select the following options from this display.

- v Creating PFD definition
- v Changing PFD definition
- v Copying PFD definition
- v Deleting PFD definition
- v Printing PFD definition
- v Renaming PFD definition
- v Printing database file

Select 11 (Work with PFD definitions) on the AFP utilities menu on page 139, and press the Enter key. The following display appears:

Screenshot

When the definition is the first PFD definition to be created, no definition list appears on the display.

Note: Before you create a PFD definition, you need to create a PFD definition file by using option 1 (Create) on the Work with PFD Definition Files display.

The following tables explain the Work with PFD Definitions display.

143

<!-- missing-key-value-item -->